# What is Patternslib?

Patternslib is a toolkit which lets you create rich, dynamic and interactive prototypes or
websites, without having to know or care about Javascript.

Instead, you simply add special CSS classes and HTML5 data attributes to your
HTML. These clasess and attributes describe and invoke so-called "interaction patterns",
which add rich functionality to your page.

Patternslib is both a library of reusable interaction patterns as well as a
small framework for creating such patterns.
